@@ -226,6 +226,7 @@ std::list<std::string> File::scanCitysets()
 
 std::list<std::string> File::scanCampaigns()
 {
+    std::string campaign;
     std::string path = getCampaignDir();
     std::list<std::string> retlist;
     Glib::Dir dir(path);
@@ -250,10 +251,12 @@ std::list<std::string> File::scanCampaigns()
     for (std::list<std::string>::iterator it = retlist.begin(); 
 	 it != retlist.end();)
       {
-	std::string campaign = Campaign::get_campaign_from_scenario_file(*it);
-	if (find (retlist.begin(), retlist.end(), campaign) != retlist.end())
+	campaign = Campaign::get_campaign_from_scenario_file(path + "/" + *it);
+	std::list<std::string>::iterator cit;
+	cit = find (retlist.begin(), retlist.end(), campaign);
+	if (cit != retlist.end())
 	  {
-	    it = retlist.erase (it);
+	    retlist.erase (cit);
 	    continue;
 	  }
 	it++;
