@@ -2,6 +2,7 @@
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003, 2006 Andrea Paternesi
 // Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2008 Janek Kozicki
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -50,6 +51,12 @@ class XML_Helper;
 class GameMap: public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
+	//! The xml tag of the itemstack subobject in a saved-game file.
+	static std::string d_itemstack_tag; 
+
         /** Singleton function to get the GameMap instance
           * 
           * @return singleton instance
@@ -154,7 +161,9 @@ class GameMap: public sigc::trackable
 	 */
 	void applyTileStyles (int minx, int miny, int maxx, int maxy,
 			      bool smooth_terrain);
+	void applyTileStyle (int i, int j);
 
+	void surroundMountains(int minx, int miny, int maxx, int maxy);
 	//! Get the positions of all of the items on the game map (in bags).
 	std::vector<Vector<int> > getItems();
 
@@ -175,12 +184,16 @@ class GameMap: public sigc::trackable
         bool isBlockedAvenue(int x, int y, int destx, int desty);
         bool isDock(int x, int y);
 	void close_circles (int minx, int miny, int maxx, int maxy);
+	void processStyles(std::string styles, int chars_per_style);
+	int determineCharsPerStyle(std::string styles);
 
 	TileStyle *calculatePreferredStyle(int i, int j);
 	void demote_lone_tile(int minx, int miny, int maxx, int maxy, 
 			      Tile::Type intype, Tile::Type outtype);
+
 	int tile_is_connected_to_other_like_tiles (Tile::Type tile, int i, 
 						   int j);
+	bool are_those_tiles_similar(Tile::Type outer_tile,Tile::Type inner_tile, bool checking_loneliness);
 
         // Data
         static GameMap* s_instance;
