@@ -26,6 +26,7 @@
 #include <sigc++/functors/mem_fun.h>
 #include <uuid/uuid.h>
 
+#include "ucompose.hpp"
 #include "GameScenario.h"
 #include "Campaign.h"
 #include "MapGenerator.h"
@@ -71,7 +72,8 @@ using namespace std;
 
 GameScenario::GameScenario(std::string name,std::string comment, bool turnmode,
 			   GameScenario::PlayMode playmode)
-    :d_name(name),d_comment(comment), d_turnmode(turnmode), d_playmode(playmode)
+    :d_name(name),d_comment(comment), d_turnmode(turnmode), 
+    d_playmode(playmode), recording_file("")
 {
     Armysetlist::getInstance();
     Tilesetlist::getInstance();
@@ -86,7 +88,7 @@ GameScenario::GameScenario(std::string name,std::string comment, bool turnmode,
 // savegame is a filename with absolute path!
 
 GameScenario::GameScenario(string savegame, bool& broken)
-  :d_turnmode(true), d_playmode(GameScenario::HOTSEAT)
+  :d_turnmode(true), d_playmode(GameScenario::HOTSEAT), recording_file("")
 {
   XML_Helper helper(savegame, ios::in, Configuration::s_zipfiles);
   broken = loadWithHelper(helper);
@@ -94,7 +96,7 @@ GameScenario::GameScenario(string savegame, bool& broken)
 }
 
 GameScenario::GameScenario(XML_Helper &helper, bool& broken)
-  : d_turnmode(true), d_playmode(GameScenario::HOTSEAT)
+  : d_turnmode(true), d_playmode(GameScenario::HOTSEAT), recording_file("")
 {
   broken = loadWithHelper(helper);
 }
@@ -446,10 +448,10 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
       debug("loading scenario")
 
       helper->getData(d_id, "id");
-      helper->getData(s_round, "turn");
       helper->getData(d_turnmode, "turnmode");
       helper->getData(d_name, "name");
       helper->getData(d_comment, "comment");
+      helper->getData(s_round, "turn");
       helper->getData(s_see_opponents_stacks, "view_enemies");
       helper->getData(s_see_opponents_production, "view_production");
       helper->getData(s_play_with_quests, "quests");
@@ -587,6 +589,21 @@ void GameScenario::nextRound()
 {
   s_round++;
 
+  if (recording_file != "")
+    {
+      XML_Helper helper(recording_file, std::ios::app, 
+			Configuration::s_zipfiles);
+      //what do i do now?
+      Playerlist *pl = Playerlist::getInstance();
+      for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
+	{
+	  (*it)->saveNetworkActions(&helper);
+	  //somehow dump the action list of each player, while 
+	  //appending to recording file.
+	}
+      helper.close();
+    }
+
   char filename[1024];
   if (Configuration::s_autosave_policy == 2)
     snprintf(filename,sizeof(filename), "autosave-%03d.sav", s_round - 1);
@@ -626,6 +643,9 @@ std::string GameScenario::playModeToString(const GameScenario::PlayMode mode)
       case GameScenario::PLAY_BY_MAIL:
 	return "GameScenario::PLAY_BY_MAIL";
 	break;
+      case GameScenario::CAMPAIGN:
+	return "GameScenario::CAMPAIGN";
+	break;
     }
   return "GameScenario::HOTSEAT";
 }
@@ -640,6 +660,8 @@ GameScenario::PlayMode GameScenario::playModeFromString(const std::string str)
     return GameScenario::NETWORKED;
   else if (str == "GameScenario::PLAY_BY_MAIL")
     return GameScenario::PLAY_BY_MAIL;
+  else if (str == "GameScenario::CAMPAIGN")
+    return GameScenario::CAMPAIGN;
   return GameScenario::HOTSEAT;
 }
 	
@@ -651,3 +673,212 @@ void GameScenario::setNewRandomId()
   uuid_unparse(uu, buf);
   d_id = buf;
 }
+	
+bool GameScenario::validate(std::list<std::string> &errors, std::list<std::string> &warnings)
+{
+  Playerlist *pl = Playerlist::getInstance();
+  Uint32 num = pl->countPlayersAlive();
+  if (num < 2)
+    errors.push_back(_("There must be at least 2 players in the scenario."));
+
+  num = Citylist::getInstance()->countCities();
+  if (num < 2)
+    errors.push_back(_("There must be at least 2 cities in the scenario."));
+
+  for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
+    {
+      if (*it == pl->getNeutral())
+	continue;
+      if ((*it)->isDead() == true)
+	continue;
+      if (Citylist::getInstance()->getFirstCity(*it) == NULL)
+	{
+	  errors.push_back(_("Every player must have at least one city in the scenario."));
+	  break;
+	}
+    }
+
+  Uint32 count = 0;
+  Citylist *cl = Citylist::getInstance();
+  for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
+    {
+      if ((*it)->isUnnamed() == true)
+	count++;
+    }
+  if (count > 0)
+    {
+      std::string s;
+      s = String::ucompose(ngettext("There is %1 unnamed city", "There are %1 unnamed cities", count), count);
+      warnings.push_back(s);
+    }
+
+  count = 0;
+  Ruinlist *rl = Ruinlist::getInstance();
+  for (Ruinlist::iterator it = rl->begin(); it != rl->end(); it++)
+    {
+      if ((*it)->isUnnamed() == true)
+	count++;
+    }
+  if (count > 0)
+    {
+      std::string s;
+      s = String::ucompose(ngettext("There is %1 unnamed ruin", "There are %1 unnamed ruins", count), count);
+      warnings.push_back(s);
+    }
+
+  count = 0;
+  Templelist *tl = Templelist::getInstance();
+  for (Templelist::iterator it = tl->begin(); it != tl->end(); it++)
+    {
+      if ((*it)->isUnnamed() == true)
+	count++;
+    }
+  if (count > 0)
+    {
+      std::string s;
+      s = String::ucompose(ngettext("There is %1 unnamed temple", "There are %1 unnamed temples", count), count);
+      warnings.push_back(s);
+    }
+
+  count = 0;
+  Stacklist *sl = Playerlist::getInstance()->getNeutral()->getStacklist();
+  for (Stacklist::iterator it = sl->begin(); it != sl->end(); it++)
+    {
+      if (Citylist::getInstance()->getObjectAt((*it)->getPos()) == NULL)
+	count++;
+    }
+  if (count > 0)
+    {
+      std::string s;
+      s = String::ucompose(ngettext("There is %1 neutral stack not in a city", "There are %1 neutral stacks not in cities", count), count);
+      warnings.push_back(s);
+    }
+
+  if (errors.size() ==  0)
+    return true;
+  return false;
+}
+
+void GameScenario::initialize(GameParameters g)
+{
+  setupFog(g.hidden_map);
+  setupCities(g.quick_start);
+  setupStacks(g.hidden_map);
+  setupDiplomacy(g.diplomacy);
+  if (s_random_turns)
+    Playerlist::getInstance()->randomizeOrder();
+  nextRound();
+  if (d_playmode == GameScenario::NETWORKED)
+    Playerlist::getInstance()->turnHumansIntoNetworkPlayers();
+}
+
+class ParamLoader
+{
+public:
+    bool loadParam(std::string tag, XML_Helper* helper)
+      {
+	if (tag == Player::d_tag)
+	  {
+	    int type;
+	    int id;
+	    std::string name;
+	    GameParameters::Player p;
+	    helper->getData(id, "id");
+	    p.id = id;
+	    helper->getData(type, "type");
+	    switch (Player::Type(type))
+	      {
+	      case Player::HUMAN: 
+		p.type = GameParameters::Player::HUMAN;
+		break;
+	      case Player::AI_FAST: 
+		p.type = GameParameters::Player::EASY;
+		break;
+	      case Player::AI_DUMMY: 
+		p.type = GameParameters::Player::EASY;
+		break;
+	      case Player::AI_SMART: 
+		p.type = GameParameters::Player::HARD;
+		break;
+	      case Player::NETWORKED: 
+		p.type = GameParameters::Player::HUMAN;
+		break;
+	      }
+	    helper->getData(name, "name");
+	    p.name = name;
+	    if (p.id != 8) //is not neutral
+	      game_params.players.push_back(p);
+	    else
+	      {
+		int armyset_id;
+		helper->getData(armyset_id, "armyset");
+		Armysetlist *al = Armysetlist::getInstance();
+		Armyset *armyset = al->getArmyset(armyset_id);
+		game_params.army_theme = armyset->getSubDir();
+	      }
+
+	    return true;
+	  }
+	if (tag == GameMap::d_tag)
+	  {
+	    helper->getData(game_params.shield_theme, "shieldset");
+	    helper->getData(game_params.tile_theme, "tileset");
+	    helper->getData(game_params.city_theme, "cityset");
+	    return true;
+	  }
+	if (tag == GameScenario::d_tag)
+	  {
+	    helper->getData(game_params.see_opponents_stacks, 
+			    "view_enemies");
+	    helper->getData(game_params.see_opponents_production, 
+			    "view_production");
+	    helper->getData(game_params.play_with_quests, "quests");
+	    helper->getData(game_params.hidden_map, "hidden_map");
+	    helper->getData(game_params.diplomacy, "diplomacy");
+	    helper->getData(game_params.cusp_of_war, "cusp_of_war");
+	    std::string neutral_cities_str;
+	    helper->getData(neutral_cities_str, "neutral_cities");
+	    game_params.neutral_cities = 
+	      Configuration::neutralCitiesFromString(neutral_cities_str);
+	    std::string razing_cities_str;
+	    helper->getData(razing_cities_str, "razing_cities");
+	    game_params.razing_cities = 
+	      Configuration::razingCitiesFromString(razing_cities_str);
+	    helper->getData(game_params.intense_combat, 
+			    "intense_combat");
+	    helper->getData(game_params.military_advisor, 
+			    "military_advisor");
+	    helper->getData(game_params.random_turns, "random_turns");
+	    return true;
+	  }
+	return false;
+      };
+    GameParameters game_params;
+};
+GameParameters GameScenario::loadGameParameters(std::string filename, bool &broken)
+{
+  ParamLoader loader;
+  
+  XML_Helper helper(filename, std::ios::in, Configuration::s_zipfiles);
+  helper.registerTag(GameMap::d_tag, 
+		     sigc::mem_fun(loader, &ParamLoader::loadParam));
+  helper.registerTag(GameScenario::d_tag, 
+		     sigc::mem_fun(loader, &ParamLoader::loadParam));
+  helper.registerTag(Player::d_tag, 
+		     sigc::mem_fun(loader, &ParamLoader::loadParam));
+  bool retval = helper.parse();
+
+  broken = !retval;
+  helper.close();
+  return loader.game_params;
+}
+
+void GameScenario::startRecordingEventsToFile(std::string filename)
+{
+  recording_file = filename;
+}
+
+void GameScenario::stopRecordingEventsToFile()
+{
+  recording_file = "";
+}
