@@ -204,13 +204,13 @@ GraphicsCache::GraphicsCache()
     loadBridgePics();
     loadCursorPics();
     loadFlags();
-    for (int i = 0; i < d_selector.size(); i++)
+    for (unsigned int i = 0; i < d_selector.size(); i++)
       {
         d_selector[i] = NULL;
         d_selectormask[i] = NULL;
       }
 
-    for (int i = 0; i < d_smallselector.size(); i++)
+    for (unsigned int i = 0; i < d_smallselector.size(); i++)
       {
         d_smallselector[i] = NULL;
         d_smallselectormask[i] = NULL;
@@ -259,24 +259,24 @@ GraphicsCache::~GraphicsCache()
         SDL_FreeSurface(d_flagmask[i]);
     }
 
-    for (int i = 0; i < d_selector.size(); i++)
+    for (unsigned int i = 0; i < d_selector.size(); i++)
     {
         SDL_FreeSurface(d_selector[i]);
         SDL_FreeSurface(d_selectormask[i]);
     }
 
-    for (int i = 0; i < d_smallselector.size(); i++)
+    for (unsigned int i = 0; i < d_smallselector.size(); i++)
     {
         SDL_FreeSurface(d_smallselector[i]);
         SDL_FreeSurface(d_smallselectormask[i]);
     }
 
-    for (int i = 0; i < PRODUCTION_SHIELD_TYPES; i++)
+    for (unsigned int i = 0; i < PRODUCTION_SHIELD_TYPES; i++)
     {
         SDL_FreeSurface(d_prodshieldpic[i]);
     }
 
-    for (int i = 0; i < MOVE_BONUS_TYPES; i++)
+    for (unsigned int i = 0; i < MOVE_BONUS_TYPES; i++)
     {
         SDL_FreeSurface(d_movebonuspic[i]);
     }
@@ -343,8 +343,7 @@ SDL_Surface* GraphicsCache::getSignpostPic()
 SDL_Surface* GraphicsCache::getMoveBonusPic(Uint32 bonus, bool has_ship)
 {
   Uint32 type;
-  if (bonus & Tile::FOREST && bonus & Tile::HILLS && bonus & Tile::WATER &&
-      bonus & Tile::MOUNTAIN && bonus & Tile::SWAMP) // show fly icon
+  if (bonus == Tile::isFlying()) // show fly icon
     type = 4; 
   else if (bonus & Tile::FOREST && bonus & Tile::HILLS) // show trees and hills
     type = 3;
@@ -1838,15 +1837,16 @@ void GraphicsCache::loadTemplePics()
       SDL_Surface* tmp;
       SDL_PixelFormat* fmt = templepics->format;
 
-      tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts, fmt->BitsPerPixel,
-				 fmt->Rmask, fmt->Gmask, 
+      tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, 
+				 ts * TEMPLE_TILE_WIDTH, ts * TEMPLE_TILE_WIDTH,
+				 fmt->BitsPerPixel, fmt->Rmask, fmt->Gmask, 
 				 fmt->Bmask, fmt->Amask);
 
       SDL_Rect r;
-      r.x = i*ts;
+      r.x = i*(templepics->w/TEMPLE_TYPES);
       r.y = 0;
-      r.w = r.h = ts;
-      SDL_BlitSurface(templepics, &r, tmp, NULL);
+      r.w = r.h = templepics->w/TEMPLE_TYPES;
+      SDL_SoftStretch(templepics, &r, tmp, NULL);
 
       d_templepic[i] = SDL_DisplayFormatAlpha(tmp);
 
@@ -1874,15 +1874,16 @@ void GraphicsCache::loadRuinPics()
       SDL_Surface* tmp;
       SDL_PixelFormat* fmt = ruinpics->format;
 
-      tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts, fmt->BitsPerPixel,
-				 fmt->Rmask, fmt->Gmask, 
+      tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, 
+				 ts * RUIN_TILE_WIDTH, ts * RUIN_TILE_WIDTH, 
+				 fmt->BitsPerPixel, fmt->Rmask, fmt->Gmask, 
 				 fmt->Bmask, fmt->Amask);
 
       SDL_Rect r;
-      r.x = i*ts;
+      r.x = i*(ruinpics->w/RUIN_TYPES);
       r.y = 0;
-      r.w = r.h = ts;
-      SDL_BlitSurface(ruinpics, &r, tmp, NULL);
+      r.w = r.h = (ruinpics->w/RUIN_TYPES);
+      SDL_SoftStretch(ruinpics, &r, tmp, NULL);
 
       d_ruinpic[i] = SDL_DisplayFormatAlpha(tmp);
 
@@ -2097,7 +2098,7 @@ void GraphicsCache::loadCityPics()
   SDL_PixelFormat *fmt;
   // GameMap has the actual cityset stored
   std::string cityset = GameMap::getInstance()->getCityset()->getSubDir();
-  int size = GameMap::getInstance()->getTileset()->getTileSize() * 2;
+  int size = GameMap::getInstance()->getTileset()->getTileSize() * CITY_TILE_WIDTH;
 
   // load the image for the razed city
   SDL_Surface* razedpics = GraphicsLoader::getCitysetPicture(cityset, "castle_razed.png");
@@ -2114,10 +2115,10 @@ void GraphicsCache::loadCityPics()
       //copy the razed city image...
 
       SDL_Rect r;
-      r.x = i * size;
+      r.x = i * (razedpics->w/(MAX_PLAYERS +1));
       r.y = 0;
-      r.w = r.h = size;
-      SDL_BlitSurface(razedpics, &r, tmp, 0);
+      r.w = r.h = (razedpics->w/(MAX_PLAYERS +1));
+      SDL_SoftStretch(razedpics, &r, tmp, 0);
 
       d_razedpic[i] = SDL_DisplayFormatAlpha(tmp);
     }
@@ -2141,10 +2142,10 @@ void GraphicsCache::loadCityPics()
       //copy the city image...
 
       SDL_Rect r;
-      r.x = i*size;
+      r.x = i*(citypics->w/(MAX_PLAYERS+1));
       r.y = 0;
-      r.w = r.h = size;
-      SDL_BlitSurface(citypics, &r, tmp, 0);
+      r.w = r.h = (citypics->w/(MAX_PLAYERS+1));
+      SDL_SoftStretch(citypics, &r, tmp, 0);
 
       d_citypic[i] = SDL_DisplayFormatAlpha(tmp);
 #if 0
@@ -2153,8 +2154,8 @@ void GraphicsCache::loadCityPics()
       d_citymask[i] = SDL_CreateRGBSurface(SDL_SWSURFACE, size, size,
 					   32, 0xFF000000, 0xFF0000, 0xFF00, 0xFF);
 
-      r.y = size;
-      SDL_BlitSurface(citypics, &r, d_citymask[i], 0);
+      r.y = citypics->h/2;
+      SDL_SoftStretch(citypics, &r, d_citymask[i], 0);
 #endif
     }
 
@@ -2214,7 +2215,7 @@ bool GraphicsCache::loadSelectorImages(std::string tileset, std::string filename
       return false;
     }
 
-  if (selpics->h != size * 2)
+  if ((unsigned int) selpics->h != size * 2)
     {
       SDL_FreeSurface (selpics);
       return false;
@@ -2252,7 +2253,6 @@ bool GraphicsCache::loadSelectorImages(std::string tileset, std::string filename
 
 void GraphicsCache::loadSelectors()
 {
-  int i;
   std::string tileset = GameMap::getInstance()->getTileset()->getSubDir();
   std::string small = GameMap::getInstance()->getTileset()->getSmallSelectorFilename();
   std::string large = GameMap::getInstance()->getTileset()->getLargeSelectorFilename();
@@ -2266,7 +2266,7 @@ void GraphicsCache::loadSelectors()
       fprintf (stderr,"Selector file %s is malformed\n", large.c_str());
       exit(1);
     }
-  for (int i = 0; i < images.size(); i++)
+  for (unsigned int i = 0; i < images.size(); i++)
     {
       d_selector.push_back(images[i]);
       d_selectormask.push_back(masks[i]);
@@ -2280,7 +2280,7 @@ void GraphicsCache::loadSelectors()
       fprintf (stderr,"Selector file %s is malformed\n", small.c_str());
       exit(1);
     }
-  for (int i = 0; i < images.size(); i++)
+  for (unsigned int i = 0; i < images.size(); i++)
     {
       d_smallselector.push_back(images[i]);
       d_smallselectormask.push_back(masks[i]);
