@@ -25,7 +25,6 @@
 #include "citylist.h"
 #include "playerlist.h"
 #include "stack.h"
-#include "defs.h"
 #include "xmlhelper.h"
 
 using namespace std;
@@ -75,7 +74,7 @@ bool QuestCityOccupy::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("quest");
+    retval &= helper->openTag(Quest::d_tag);
     retval &= Quest::save(helper);
     retval &= helper->saveData("city", d_city);
     retval &= helper->closeTag();
@@ -108,8 +107,8 @@ City* QuestCityOccupy::getCity() const
 {
     Citylist* cl = Citylist::getInstance();
     for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
-        if ((*it).getId() == d_city)
-            return &(*it);
+        if ((*it)->getId() == d_city)
+            return (*it);
 
     return 0;
 }
@@ -132,9 +131,9 @@ City * QuestCityOccupy::chooseToOccupy(Player *p)
   // Collect all cities
   Citylist* cl = Citylist::getInstance();
   for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
-    if (!(*it).isBurnt() && (*it).getOwner() != p &&
-	(*it).getOwner() != Playerlist::getInstance()->getNeutral())
-      cities.push_back(&(*it));
+    if (!(*it)->isBurnt() && (*it)->getOwner() != p &&
+	(*it)->getOwner() != Playerlist::getInstance()->getNeutral())
+      cities.push_back((*it));
 
   // Find a suitable city for us to occupy
   if (cities.empty())
