@@ -250,6 +250,10 @@ class City : public Ownable, public Location, public Renamable,
 	//! This makes the army show up.  called when it's time.
 	const Army *armyArrives();
 
+	bool isUnnamed() {return getName() == getDefaultName() ? true : false;};
+
+	static std::string getDefaultName() {return DEFAULT_CITY_NAME;};
+
     private:
 
 	bool load(std::string tag, XML_Helper *helper);
