@@ -16,6 +16,7 @@
 //  02110-1301, USA.
 
 #include <iostream>
+#include <algorithm>
 #include <expat.h>
 #include <SDL_image.h>
 #include <SDL.h>
@@ -23,6 +24,7 @@
 #include <sigc++/functors/mem_fun.h>
 
 #include "citysetlist.h"
+#include "ucompose.hpp"
 #include "File.h"
 #include "defs.h"
 
@@ -61,7 +63,7 @@ Citysetlist::Citysetlist()
 	iterator it = end();
 	it--;
 	(*it)->setSubDir(*i);
-	d_dirs[(*it)->getName()] = *i;
+	d_dirs[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = *i;
 	d_citysets[*i] = *it;
       }
 }
@@ -80,9 +82,18 @@ std::list<std::string> Citysetlist::getNames()
   return names;
 }
 
+std::list<std::string> Citysetlist::getNames(Uint32 tilesize)
+{
+  std::list<std::string> names;
+  for (iterator it = begin(); it != end(); it++)
+    if ((*it)->getTileSize() == tilesize)
+      names.push_back((*it)->getName());
+  return names;
+}
+
 bool Citysetlist::load(std::string tag, XML_Helper *helper)
 {
-  if (tag == "cityset")
+  if (tag == Cityset::d_tag)
     {
       Cityset *cityset = new Cityset(helper);
       push_back(cityset); 
@@ -96,7 +107,7 @@ bool Citysetlist::loadCityset(std::string name)
 
   XML_Helper helper(File::getCityset(name), ios::in, false);
 
-  helper.registerTag("cityset", sigc::mem_fun((*this), &Citysetlist::load));
+  helper.registerTag(Cityset::d_tag, sigc::mem_fun((*this), &Citysetlist::load));
 
   if (!helper.parse())
     {
@@ -107,3 +118,17 @@ bool Citysetlist::loadCityset(std::string name)
 
   return true;
 }
+
+void Citysetlist::getSizes(std::list<Uint32> &sizes)
+{
+  for (iterator i = begin(); i != end(); i++)
+    {
+      if (find (sizes.begin(), sizes.end(), (*i)->getTileSize()) == sizes.end())
+	sizes.push_back((*i)->getTileSize());
+    }
+}
+
+std::string Citysetlist::getCitysetDir(std::string name, Uint32 tilesize)
+{
+  return d_dirs[String::ucompose("%1 %2", name, tilesize)];
+}
