@@ -24,11 +24,12 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/table.h>
 
-#include "../player.h"
+#include "player.h"
 
+#include "decorated.h"
 //
 //
-class DiplomacyReportDialog: public sigc::trackable
+class DiplomacyReportDialog: public Decorated
 {
  public:
     DiplomacyReportDialog(Player *player);
