@@ -60,6 +60,8 @@
 #include "recently-played-game-list.h"
 #include "Backpack.h"
 #include "Item.h"
+#include "city.h"
+#include "FogMap.h"
 
 Driver::Driver(std::string load_filename)
 {
@@ -67,6 +69,8 @@ Driver::Driver(std::string load_filename)
     splash_window.reset(new SplashWindow);
     splash_window->new_game_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_new_game_requested));
+    splash_window->new_campaign_requested.connect(
+	sigc::mem_fun(*this, &Driver::on_new_campaign_requested));
     splash_window->new_hosted_network_game_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_new_hosted_network_game_requested));
     splash_window->new_remote_network_game_requested.connect(
@@ -268,7 +272,8 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
     if (splash_window.get())
 	splash_window->hide();
 
-    NewGameProgressWindow pw(g, GameScenario::NETWORKED);
+    NewGameProgressWindow pw(g, GameScenario::NETWORKED, 
+			     Main::instance().record);
     Gtk::Main::instance()->run(pw);
     GameScenario *game_scenario = pw.getGameScenario();
 
@@ -438,7 +443,8 @@ void Driver::on_new_game_requested(GameParameters g)
     if (splash_window.get())
 	splash_window->hide();
 
-    NewGameProgressWindow pw(g, GameScenario::HOTSEAT);
+    NewGameProgressWindow pw(g, GameScenario::HOTSEAT, 
+			     Main::instance().record);
     Gtk::Main::instance()->run(pw);
     GameScenario *game_scenario = pw.getGameScenario();
 
@@ -448,6 +454,61 @@ void Driver::on_new_game_requested(GameParameters g)
 				  _("Corrupted saved game file."), 0);
 	dialog.run();
 	dialog.hide();
+	splash_window->show();
+	return;
+      }
+
+    std::list<std::string> e, w;
+    if (g.map_path != "" && game_scenario->validate(e, w) == false)
+      {
+	TimedMessageDialog dialog
+	  (*splash_window->get_window(), 
+	   _("Invalid map file.\n" 
+	     "Please validate it in the scenario editor."), 0);
+	dialog.run();
+	dialog.hide();
+	splash_window->show();
+	return;
+      }
+
+    NextTurn *next_turn = new NextTurnHotseat(game_scenario->getTurnmode(),
+					      game_scenario->s_random_turns);
+    init_game_window();
+    
+    game_window->show();
+    game_window->new_game(game_scenario, next_turn);
+}
+
+void Driver::on_new_campaign_requested(GameParameters g)
+{
+    if (splash_window.get())
+	splash_window->hide();
+
+    NewGameProgressWindow pw(g, GameScenario::CAMPAIGN,
+			     Main::instance().record);
+    Gtk::Main::instance()->run(pw);
+    GameScenario *game_scenario = pw.getGameScenario();
+
+    if (game_scenario == NULL)
+      {
+	TimedMessageDialog dialog(*splash_window->get_window(),
+				  _("Corrupted saved game file."), 0);
+	dialog.run();
+	dialog.hide();
+	splash_window->show();
+	return;
+      }
+
+    std::list<std::string> e, w;
+    if (g.map_path != "" && game_scenario->validate(e, w) == false)
+      {
+	TimedMessageDialog dialog
+	  (*splash_window->get_window(), 
+	   _("Invalid map file.\n" 
+	     "Please validate it in the scenario editor."), 0);
+	dialog.run();
+	dialog.hide();
+	splash_window->show();
 	return;
       }
 
@@ -507,7 +568,7 @@ void Driver::on_game_ended()
   if (game_window.get())
     {
       game_window->hide();
-      game_window.reset();
+      //game_window.reset();
     }
   GameClient::deleteInstance();
   PbmGameClient::deleteInstance();
@@ -519,24 +580,60 @@ void Driver::on_game_ended()
   splash_window->show();
 }
 
-void Driver::on_next_scenario(std::string scenario, int num_heroes)
+void Driver::on_next_scenario(std::string scenario, int gold, std::list<Hero*> heroes, std::string player_name)
 {
+
   GameClient::deleteInstance();
   PbmGameClient::deleteInstance();
   GameServer::deleteInstance();
   PbmGameServer::deleteInstance();
 
-  GraphicsCache::deleteInstance();
+  //remove load_opts stuff from GameScenario, etc
+  
+  //load up the next scenario 
+  GameParameters g;
+  //players is empty
+  bool broken = false;
+  g = GameScenario::loadGameParameters(scenario, broken);
+  g.map_path = scenario;
+  //go get players from scenario file
+  g.see_opponents_stacks = GameScenarioOptions::s_see_opponents_stacks;
+  g.see_opponents_production = GameScenarioOptions::s_see_opponents_production;
+  g.play_with_quests = GameScenarioOptions::s_play_with_quests;
+  g.hidden_map = GameScenarioOptions::s_hidden_map;
+  g.diplomacy = GameScenarioOptions::s_diplomacy;
+  g.neutral_cities = GameScenarioOptions::s_neutral_cities;
+  g.razing_cities = GameScenarioOptions::s_razing_cities;
+  g.cusp_of_war = GameScenarioOptions::s_cusp_of_war;
+  g.intense_combat = GameScenarioOptions::s_intense_combat;
+  g.military_advisor = GameScenarioOptions::s_military_advisor;
+  g.random_turns = GameScenarioOptions::s_random_turns;
+  g.quick_start = false;
 
-  Player *p = Playerlist::getInstance()->getFirstLiving();
+  Uint32 player_id = 0;
+  for (std::vector<GameParameters::Player>::iterator
+       i = g.players.begin(), end = g.players.end(); i != end; ++i) 
+    {
+      if ((*i).type == GameParameters::Player::HUMAN)
+	{
+	  player_id = (Uint32) (*i).id;
+	  (*i).name = player_name;
+	  break;
+	}
+    }
 
-  std::list<Hero*> heroes = p->getStacklist()->getTopHeroes(num_heroes);
+  game_window->hide();
+  NewGameProgressWindow pw(g, GameScenario::CAMPAIGN,
+			   Main::instance().record);
+  Gtk::Main::instance()->run(pw);
+  GameScenario *game_scenario = pw.getGameScenario();
 
-  //load the game again
-  GameScenario *game_scenario = load_game(scenario);
-
-
-  Player *player = Playerlist::getInstance()->getFirstHuman();
+  Player *player = Playerlist::getInstance()->getPlayer(player_id);
+  player->withdrawGold(player->getGold());
+  if (gold > MAX_GOLD_TO_CARRY_OVER_TO_NEXT_SCENARIO)
+    gold = MAX_GOLD_TO_CARRY_OVER_TO_NEXT_SCENARIO;
+  player->addGold(gold);
+  player->setName(player_name);
   City *c = Citylist::getInstance()->getFirstCity(player);
 
   for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end(); it++)
@@ -547,10 +644,15 @@ void Driver::on_next_scenario(std::string scenario, int num_heroes)
       Backpack *backpack = (*it)->getBackpack();
       for (Backpack::iterator i = backpack->begin(); i != backpack->end(); i++)
 	(*i)->assignNewId();
+      (*it)->setOwner(player);
       c->addArmy(*it);
     }
 
-  delete game_scenario;
+  NextTurnHotseat *nextTurn;
+  nextTurn = new NextTurnHotseat(game_scenario->getTurnmode(),
+				 game_scenario->s_random_turns);
+  game_window->show();
+  game_window->new_game (game_scenario, nextTurn);
 }
 
 void Driver::init_game_window()
@@ -652,6 +754,8 @@ GameScenario *Driver::load_game(std::string file_path)
 	dialog.hide();
 	return NULL;
       }
+    if (Main::instance().record != "")
+      game_scenario->startRecordingEventsToFile(Main::instance().record);
     return game_scenario;
 }
 
@@ -660,7 +764,8 @@ void Driver::on_new_pbm_game_requested(GameParameters g)
   std::string filename;
   std::string temp_filename = File::getSavePath() + "pbmtmp.sav";
       
-  NewGameProgressWindow pw(g, GameScenario::PLAY_BY_MAIL);
+  NewGameProgressWindow pw(g, GameScenario::PLAY_BY_MAIL,
+			   Main::instance().record);
   Gtk::Main::instance()->run(pw);
   GameScenario *game_scenario = pw.getGameScenario();
   if (game_scenario == NULL)
@@ -784,6 +889,8 @@ void Driver::stress_test()
   if (broken)
     return;
 
+  if (Main::instance().record != "")
+    game_scenario->startRecordingEventsToFile(Main::instance().record);
   NextTurnHotseat *nextTurn;
   nextTurn = new NextTurnHotseat(game_scenario->getTurnmode(),
 				 game_scenario->s_random_turns);
@@ -795,10 +902,7 @@ void Driver::stress_test()
   if (game_scenario->getRound() == 0)
     {
       Playerlist::getInstance()->syncPlayers(g.players);
-      game_scenario->setupFog(g.hidden_map);
-      game_scenario->setupCities(g.quick_start);
-      game_scenario->setupDiplomacy(g.diplomacy);
-      game_scenario->nextRound();
+      game_scenario->initialize(g);
     }
 
   nextTurn->start();
