@@ -223,6 +223,7 @@ void GamePreferencesDialog::init()
 
 GamePreferencesDialog::GamePreferencesDialog(GameScenario::PlayMode play_mode)
 {
+  d_campaign = false;
   mode = play_mode;
   init();
   if (mode != GameScenario::NETWORKED)
@@ -233,9 +234,12 @@ GamePreferencesDialog::GamePreferencesDialog(GameScenario::PlayMode play_mode)
 
 }
 
-GamePreferencesDialog::GamePreferencesDialog(std::string filename)
+GamePreferencesDialog::GamePreferencesDialog(std::string filename, bool campaign)
 {
+  d_campaign = campaign;
   mode = GameScenario::HOTSEAT;
+  if (campaign)
+    mode = GameScenario::CAMPAIGN;
   init ();
   delete game_name_label;
   delete game_name_entry;
@@ -243,8 +247,12 @@ GamePreferencesDialog::GamePreferencesDialog(std::string filename)
   load_map_filechooser->set_filename(filename);
   load_map_radio->set_sensitive(false);
   random_map_radio->set_sensitive(false);
-  load_map_filechooser->set_sensitive(false);
-  dialog->set_title(_("New Scenario"));
+  //load_map_filechooser->set_sensitive(false);
+  load_map_filechooser->set_child_visible(false);
+  if (campaign)
+    dialog->set_title(_("New Campaign"));
+  else
+    dialog->set_title(_("New Scenario"));
 }
 
 GamePreferencesDialog::~GamePreferencesDialog()
@@ -658,17 +666,17 @@ void GamePreferencesDialog::on_start_game_clicked()
 
     g.process_armies = GameParameters::PROCESS_ARMIES_AT_PLAYERS_TURN;
 
-    g.see_opponents_stacks = Configuration::s_see_opponents_stacks;
-    g.see_opponents_production = Configuration::s_see_opponents_production;
-    g.play_with_quests = Configuration::s_play_with_quests;
-    g.hidden_map = Configuration::s_hidden_map;
-    g.neutral_cities = Configuration::s_neutral_cities;
-    g.razing_cities = Configuration::s_razing_cities;
-    g.diplomacy = Configuration::s_diplomacy;
-    g.random_turns = Configuration::s_random_turns;
+    g.see_opponents_stacks = GameScenarioOptions::s_see_opponents_stacks;
+    g.see_opponents_production = GameScenarioOptions::s_see_opponents_production;
+    g.play_with_quests = GameScenarioOptions::s_play_with_quests;
+    g.hidden_map = GameScenarioOptions::s_hidden_map;
+    g.neutral_cities = GameScenarioOptions::s_neutral_cities;
+    g.razing_cities = GameScenarioOptions::s_razing_cities;
+    g.diplomacy = GameScenarioOptions::s_diplomacy;
+    g.random_turns = GameScenarioOptions::s_random_turns;
     g.quick_start = Configuration::s_quick_start;
-    g.intense_combat = Configuration::s_intense_combat;
-    g.military_advisor = Configuration::s_military_advisor;
+    g.intense_combat = GameScenarioOptions::s_intense_combat;
+    g.military_advisor = GameScenarioOptions::s_military_advisor;
     g.cities_can_produce_allies = 
       cities_can_produce_allies_checkbutton->get_active();
 
@@ -854,76 +862,43 @@ void GamePreferencesDialog::on_map_chosen()
   std::string selected_filename = load_map_filechooser->get_filename();
   if (selected_filename.empty())
     return;
-  //try to read the file, grab the players
-  XML_Helper helper(selected_filename, std::ios::in, Configuration::s_zipfiles);
-
-  load_map_parameters.players.clear();
-  helper.registerTag("player",
-		     sigc::mem_fun(this, &GamePreferencesDialog::scan_players));
-  helper.registerTag("map",
-		     sigc::mem_fun(this, &GamePreferencesDialog::scan_shieldset));
-
-  if (!helper.parse())
-    {
-      std::cerr << "Error: Could not parse " << selected_filename << std::endl;
-      load_map_filechooser->set_filename("");
-      return;
-    }
-  helper.close();
+  bool broken;
+  load_map_parameters = GameScenario::loadGameParameters(selected_filename,
+							 broken);
+  if (broken)
+    return;
+  on_random_map_toggled();
   update_shields();
   on_player_type_changed();
-  return;
-}
 
-bool GamePreferencesDialog::scan_shieldset(std::string tag, XML_Helper* helper)
-{
-    if (tag == "map")
-      {
-        helper->getData(load_map_parameters.shield_theme, "shieldset");
-      }
-    return true;
-}
-
-bool GamePreferencesDialog::scan_players(std::string tag, XML_Helper* helper)
-{
-    if (tag == "player")
+  //loop through all players, making the non-humans unsensitive
+  if (d_campaign)
     {
-        int type;
-	int id;
-	std::string name;
-        if (helper->getVersion() != LORDSAWAR_SAVEGAME_VERSION)
-        {
-            std::cerr << "scenario has wrong version, we want "
-		      << LORDSAWAR_SAVEGAME_VERSION <<",\n"
-		      << "scenario offers " << helper->getVersion() <<".\n";
-            return false;
-        }
-
-	GameParameters::Player p;
-        helper->getData(id, "id");
-	p.id = id;
-        helper->getData(type, "type");
-	switch (Player::Type(type))
-	  {
-	  case Player::HUMAN: p.type = GameParameters::Player::HUMAN;
-	    break;
-	  case Player::AI_FAST: p.type = GameParameters::Player::EASY;
-	    break;
-	  case Player::AI_DUMMY: p.type = GameParameters::Player::EASY;
-	    break;
-	  case Player::AI_SMART: p.type = GameParameters::Player::HARD;
-	    break;
-	  case Player::NETWORKED: p.type = GameParameters::Player::HUMAN;
-	    break;
-	  }
-        helper->getData(name, "name");
-	p.name = name;
-	if (p.id != 8) //is not neutral
-	  load_map_parameters.players.push_back(p);
-	on_random_map_toggled();
+      bool force = false;
+      std::list<CycleButton *>::iterator c = player_types.begin();
+      std::list<Gtk::Entry *>::iterator e = player_names.begin();
+      for (; c != player_types.end(); c++, e++)
+	{
+	  if ((*c)->get_active_text() != HUMAN_PLAYER_TYPE)
+	    {
+	      (*c)->set_sensitive(false);
+	      (*e)->set_sensitive(false);
+	    }
+	  else if ((*c)->get_active_text() == HUMAN_PLAYER_TYPE && force)
+	    {
+	      (*c)->set_sensitive(true);
+	      (*c)->set_active(1);
+	      (*c)->set_sensitive(false);
+	      (*e)->set_sensitive(false);
+	    }
+	  else if ((*c)->get_active_text() == HUMAN_PLAYER_TYPE)
+	    {
+	      force = true;
+	      (*c)->set_sensitive(false);
+	    }
+	}
     }
-
-    return true;
+  return;
 }
 
 void GamePreferencesDialog::set_title(std::string text)
