@@ -91,6 +91,7 @@
 #include "GameScenarioOptions.h"
 #include "army.h"
 #include "ruin.h"
+#include "ruinlist.h"
 #include "path.h"
 #include "player.h"
 #include "stacklist.h"
@@ -100,6 +101,7 @@
 #include "hero.h"
 #include "heroproto.h"
 #include "temple.h"
+#include "templelist.h"
 #include "city.h"
 #include "Quest.h"
 #include "QuestsManager.h"
@@ -128,6 +130,7 @@
 #include "NextTurnNetworked.h"
 #include "pbm-game-server.h"
 #include "network_player.h"
+#include "Campaign.h"
 
 
 GameWindow::GameWindow()
@@ -159,8 +162,12 @@ GameWindow::GameWindow()
 		  group_ungroup_toggle));
     xml->get_widget("terrain_image", terrain_image);
     xml->get_widget("stats_box", stats_box);
+    xml->get_widget("progress_box", progress_box);
+    xml->get_widget("turn_progressbar", turn_progressbar);
+    xml->get_widget("progress_status_label", progress_status_label);
     stack_info_box->hide();
-    stats_box->show();
+    stats_box->hide();
+    progress_box->show();
 
     // the map image
     xml->get_widget("map_image", map_image);
@@ -340,8 +347,6 @@ GameWindow::GameWindow()
 	menubar->set_style(copy);
       }
 
-
-
 }
 
 GameWindow::~GameWindow()
@@ -638,6 +643,12 @@ void GameWindow::setup_signals(GameScenario *game_scenario)
   connections.push_back 
     (game->sidebar_stats_changed.connect
      (sigc::mem_fun(*this, &GameWindow::on_sidebar_stats_changed)));
+  connections.push_back 
+    (game->progress_status_changed.connect
+     (sigc::mem_fun(*this, &GameWindow::on_progress_status_changed)));
+  connections.push_back 
+    (game->progress_changed.connect
+     (sigc::mem_fun(*this, &GameWindow::on_progress_changed)));
   connections.push_back
     (game->smallmap_changed.connect
      (sigc::mem_fun(*this, &GameWindow::on_smallmap_changed)));
@@ -822,6 +833,7 @@ void GameWindow::update_diplomacy_button (bool sensitive)
 
 bool GameWindow::setup_game(GameScenario *game_scenario, NextTurn *nextTurn)
 {
+  currently_selected_stack = NULL;
   Playerlist *pl = Playerlist::getInstance();
   Armysetlist *al = Armysetlist::getInstance();
   for (Playerlist::iterator i = pl->begin(); i != pl->end(); i++)
@@ -1053,9 +1065,13 @@ void GameWindow::on_game_stopped()
 {
   game.reset();
   if (stop_action == "quit" || stop_action == "game-over")
+    {
       game_ended.emit();
+    }
   else if (stop_action == "next-scenario")
-      next_scenario.emit(d_scenario, d_num_heroes);
+    {
+      next_scenario.emit(d_scenario, d_gold, d_heroes, d_player_name);
+    }
   else if (stop_action == "load-game")
     {
       bool broken = false;
@@ -1067,7 +1083,8 @@ void GameWindow::on_game_stopped()
 	  game_ended.emit();
 	  return;
 	}
-      if (game_scenario->getPlayMode() == GameScenario::HOTSEAT)
+      if (game_scenario->getPlayMode() == GameScenario::HOTSEAT ||
+	  game_scenario->getPlayMode() == GameScenario::CAMPAIGN)
 	load_game(game_scenario, 
 		  new NextTurnHotseat(game_scenario->getTurnmode(),
 				      game_scenario->s_random_turns));
@@ -1334,6 +1351,17 @@ void GameWindow::on_ruin_report_activated()
   if (currently_selected_stack)
     pos = currently_selected_stack->getPos();
 
+  if (Templelist::getInstance()->size() == 0 &&
+      Ruinlist::getInstance()->size() == 0)
+    {
+      std::string s = _("No ruins or temples to show!");
+      TimedMessageDialog dialog(*window.get(), s, 30);
+
+      dialog.show_all();
+      dialog.run();
+      dialog.hide();
+      return;
+    }
   RuinReportDialog d(pos);
   d.set_parent_window(*window.get());
   d.run();
@@ -1519,12 +1547,31 @@ void GameWindow::stop_game(std::string action)
     }
 }
 
-void GameWindow::on_next_scenario(std::string scenario, int num_heroes)
+void GameWindow::on_next_scenario(std::string scenario, int gold, std::list<Hero*> heroes, std::string name)
 {
   //fixme: show a message here.  we won, but there's another scenario to go
   d_scenario = scenario;
-  d_num_heroes = num_heroes;
+  d_gold = gold;
+  d_heroes = heroes;
+  if (d_heroes.size() > 0)
+    {
+      Glib::ustring s;
+      s = String::ucompose
+	(ngettext("%1 hero rallies to the call of battle!",
+		  "%1 heroes rally to the call of battle!", d_heroes.size()), 
+	 d_heroes.size());
+      TimedMessageDialog dialog(*window.get(), s, 30);
+      dialog.show_all();
+      dialog.run();
+      dialog.hide();
+      HeroLevelsDialog d((*heroes.front()).getOwner());
+      d.set_parent_window(*window.get());
+      d.run();
+      d.hide();
+    }
+  d_player_name = name;
   stop_game("next-scenario");
+  //now go to on_game_stopped
 }
 
 void GameWindow::on_game_over(Player *winner)
@@ -1693,6 +1740,16 @@ void GameWindow::ensure_one_army_button_active()
     }
 }
 
+void GameWindow::on_progress_status_changed(std::string string)
+{
+  progress_status_label->set_markup("<b>" + string + "</b>");
+}
+
+void GameWindow::on_progress_changed()
+{
+  turn_progressbar->pulse();
+}
+
 void GameWindow::on_sidebar_stats_changed(SidebarStats s)
 {
   if (Configuration::s_decorated)
@@ -1731,7 +1788,12 @@ void GameWindow::on_stack_info_changed(Stack *s)
   currently_selected_stack = s;
 
   if (!s)
-    show_stats();
+    {
+      if (Playerlist::getActiveplayer()->getType() == Player::HUMAN)
+	show_stats();
+      else
+	show_progress();
+    }
   else
     {
       if (s->getOwner()->getType() == Player::HUMAN)
@@ -1741,7 +1803,7 @@ void GameWindow::on_stack_info_changed(Stack *s)
 	  show_stack(s);
 	}
       else
-	show_stats();
+	show_progress();
     }
   return;
 }
@@ -1755,9 +1817,22 @@ void GameWindow::show_stats()
   stack_info_box->get_parent()->property_height_request() = height;
   stats_box->get_parent()->property_height_request() = height;
   stack_info_container->hide();
+  progress_box->hide();
   stats_box->show();
 }
 
+void GameWindow::show_progress()
+{
+  turn_progressbar->property_fraction() = 0.0;
+  if (Playerlist::getActiveplayer() == Playerlist::getInstance()->getNeutral())
+    progress_status_label->set_text("");
+  else
+    progress_status_label->set_markup("<b>" + Playerlist::getActiveplayer()->getName() + "</b>");
+  stats_box->hide();
+  stack_info_container->hide();
+  progress_box->show();
+}
+
 void GameWindow::fill_in_group_info (Stack *s)
 {
   Uint32 bonus = s->calculateMoveBonus();
@@ -1766,7 +1841,10 @@ void GameWindow::fill_in_group_info (Stack *s)
   terrain_image->property_pixbuf() = to_pixbuf(terrain);
   group_moves_label->set_text(String::ucompose("%1",
 					       s->getGroupMoves()));
+  //printf ("toggling group/ungroup!\n");
+  group_ungroup_toggle->set_sensitive(false);
   group_ungroup_toggle->set_active(s->isGrouped());
+  group_ungroup_toggle->set_sensitive(true);
 }
 
 void GameWindow::show_stack(Stack *s)
@@ -1774,6 +1852,7 @@ void GameWindow::show_stack(Stack *s)
   GraphicsCache *gc = GraphicsCache::getInstance();
   s->sortForViewing (true);
   stats_box->hide();
+  progress_box->hide();
 
   army_buttons.clear(); 
   for (Stack::iterator i = s->begin(), end = s->end(); i != end; ++i)
@@ -2644,6 +2723,8 @@ void GameWindow::on_ruin_visited(Ruin *ruin)
 
 void GameWindow::show_shield_turn()
 {
+  Gdk::Color black("black");
+  Gdk::Color white("white");
   Playerlist* pl = Playerlist::getInstance();
   GraphicsCache *gc = GraphicsCache::getInstance();
   unsigned int c = 0;
@@ -2659,9 +2740,9 @@ void GameWindow::show_shield_turn()
 	  continue;
 	}
       if (*i == pl->getActiveplayer())
-	shield_image[c]->get_parent()->modify_bg(Gtk::STATE_NORMAL, shield_image[c]->get_parent()->get_style()->get_black());
+	shield_image[c]->get_parent()->modify_bg(Gtk::STATE_NORMAL, black);
       else
-	shield_image[c]->get_parent()->modify_bg(Gtk::STATE_NORMAL, shield_image[c]->get_parent()->get_style()->get_white());
+	shield_image[c]->get_parent()->modify_bg(Gtk::STATE_NORMAL, white);
       shield_image[c]->property_pixbuf()=to_pixbuf(gc->getShieldPic(1,(*i)));
       c++;
     }
@@ -2671,13 +2752,11 @@ void GameWindow::show_shield_turn()
 
 void GameWindow::on_remote_next_player_turn()
 {
-  printf ("updating turn indicator now!\n");
   std::auto_ptr<Gtk::Dialog> dialog;
 
+  on_stack_info_changed(NULL);
   while (g_main_context_iteration(NULL, FALSE)); //doEvents
 
-  if (Playerlist::isFinished()) //closed window while ai player moves
-    return;
   d_quick_fights = false;
   show_shield_turn();
   turn_label->set_markup(String::ucompose("Turn %1", 
@@ -2688,10 +2767,10 @@ void GameWindow::on_next_player_turn(Player *player, unsigned int turn_number)
 {
   std::auto_ptr<Gtk::Dialog> dialog;
 
+  on_stack_info_changed(NULL);
+
   while (g_main_context_iteration(NULL, FALSE)); //doEvents
 
-  if (Playerlist::isFinished()) //closed window while ai player moves
-    return;
   d_quick_fights = false;
   show_shield_turn();
   if (player->getType() != Player::HUMAN)
