@@ -34,6 +34,7 @@
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/box.h>
 #include <gtkmm/checkmenuitem.h>
+#include <gtkmm/progressbar.h>
 #include <gtkmm/menubar.h>
 
 #include "army-info-tip.h"
@@ -100,7 +101,7 @@ class GameWindow: public Decorated
     sigc::signal<void> game_ended;
     
     // emitted when we're in a campaign, and we want to go to the next scenario
-    sigc::signal<void, std::string, int> next_scenario;
+    sigc::signal<void, std::string, int, std::list<Hero*>, std::string > next_scenario;
     
     sigc::signal<void> show_lobby;
 
@@ -143,6 +144,9 @@ class GameWindow: public Decorated
     Gtk::Label *group_moves_label;
     Gtk::Image *terrain_image;
     Gtk::Box *stats_box;
+    Gtk::Box *progress_box;
+    Gtk::ProgressBar *turn_progressbar;
+    Gtk::Label *progress_status_label;
     Gtk::Image *map_image;
 
     Gtk::Label *cities_stats_label;
@@ -242,6 +246,7 @@ class GameWindow: public Decorated
     
     // info pane at the bottom
     void show_stats();
+    void show_progress();
     void show_stack(Stack *s);
     void fill_in_group_info (Stack *s);
     void on_army_toggled(Gtk::ToggleButton *toggle, Army *army);
@@ -257,6 +262,8 @@ class GameWindow: public Decorated
 
     // game callbacks
     void on_sidebar_stats_changed(SidebarStats s);
+    void on_progress_status_changed(std::string status);
+    void on_progress_changed();
     void on_smallmap_changed(SDL_Surface *map);
     void on_smallmap_slid(Rectangle view);
     void on_bigmap_cursor_changed(GraphicsCache::CursorType cursor);
@@ -289,7 +296,7 @@ class GameWindow: public Decorated
     Army::Stat on_army_gains_level(Army *army);
     void on_game_loaded(Player *player);
     void on_game_over(Player *winner);
-    void on_next_scenario(std::string scenario, int num_heroes);
+    void on_next_scenario(std::string scenario, int gold, std::list<Hero*> heroes, std::string player_name);
     void on_player_died(Player *player);
     void on_advice_asked(float percent);
     void end_turn_play_by_mail ();
@@ -321,7 +328,9 @@ public:
     bool d_quick_fights; //do we speed up fights for this player's turn?
     std::string stop_action; //hackhackhack
     std::string d_scenario;
-    int d_num_heroes;
+    int d_gold;
+    std::list<Hero*> d_heroes;
+    std::string d_player_name;
     std::string d_load_filename;
 };
 
