@@ -6,21 +6,24 @@
 
 Glib::StaticMutex mutex = GLIBMM_STATIC_MUTEX_INIT;
  
-NewGameProgressWindow::NewGameProgressWindow(GameParameters g, GameScenario::PlayMode mode)
-: game_params(g), m_end_thread(false), m_vbox(false,10), d_play_mode(mode)
+NewGameProgressWindow::NewGameProgressWindow(GameParameters g, GameScenario::PlayMode mode, std::string recording_file)
+: game_params(g), m_end_thread(false), m_vbox(false,10), d_play_mode(mode),
+    d_recording_file(recording_file)
 {
   add(m_vbox);
   m_vbox.set_border_width(10);
   m_vbox.pack_start(m_label);
   m_vbox.pack_start(m_pbar);
+  property_default_width() = 320;
  
   m_dispatcher.connect( sigc::mem_fun( m_pbar , &Gtk::ProgressBar::pulse ));
 
+  set_title(_("Please wait..."));
+  m_label.set_text(_("Generating."));
   m_thread = Glib::Thread::create( sigc::mem_fun(*this,&NewGameProgressWindow::thread_worker),true);
 
   d_game_scenario = NULL;
 
-  set_title(_("Generating."));
   show_all();
 }
 
@@ -37,6 +40,7 @@ NewGameProgressWindow::~NewGameProgressWindow()
 
 void NewGameProgressWindow::thread_worker()
 {
+  sleep(2);
   bool update_uuid = false;
   m_dispatcher();
   if (game_params.map_path.empty()) 
@@ -51,11 +55,26 @@ void NewGameProgressWindow::thread_worker()
 
   m_dispatcher();
   bool broken = false;
+						 
   GameScenario* game_scenario = new GameScenario(game_params.map_path, broken);
 
+  GameScenarioOptions::s_see_opponents_stacks=game_params.see_opponents_stacks;
+  GameScenarioOptions::s_see_opponents_production=game_params.see_opponents_production;
+  GameScenarioOptions::s_play_with_quests=game_params.play_with_quests;
+  GameScenarioOptions::s_hidden_map=game_params.hidden_map;
+  GameScenarioOptions::s_diplomacy=game_params.diplomacy;
+  GameScenarioOptions::s_cusp_of_war=game_params.cusp_of_war;
+  GameScenarioOptions::s_neutral_cities=game_params.neutral_cities;
+  GameScenarioOptions::s_razing_cities=game_params.razing_cities;
+  GameScenarioOptions::s_intense_combat=game_params.intense_combat;
+  GameScenarioOptions::s_military_advisor=game_params.military_advisor;
+  GameScenarioOptions::s_random_turns=game_params.random_turns;
+
   if (broken)
     return;
 
+  if (d_recording_file != "")
+    game_scenario->startRecordingEventsToFile(d_recording_file);
   game_scenario->setName(game_params.name);
   game_scenario->setPlayMode(d_play_mode);
 
@@ -68,20 +87,7 @@ void NewGameProgressWindow::thread_worker()
 
       m_dispatcher();
 
-      game_scenario->setupFog(game_params.hidden_map);
-      m_dispatcher();
-      game_scenario->setupCities(game_params.quick_start);
-      m_dispatcher();
-      game_scenario->setupStacks(game_params.hidden_map);
-      m_dispatcher();
-      game_scenario->setupDiplomacy(game_params.diplomacy);
-      m_dispatcher();
-      if (game_scenario->s_random_turns)
-	Playerlist::getInstance()->randomizeOrder();
-      m_dispatcher();
-      game_scenario->nextRound();
-      if (d_play_mode == GameScenario::NETWORKED)
-	Playerlist::getInstance()->turnHumansIntoNetworkPlayers();
+      game_scenario->initialize(game_params);
 
       m_dispatcher();
 
