@@ -26,14 +26,16 @@
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/entry.h>
 
-#include "../questmap.h"
-#include "../Quest.h"
-#include "../reward.h"
+#include "questmap.h"
+#include "Quest.h"
+#include "reward.h"
 
 struct SDL_Surface;
 
+#include "decorated.h"
+
 // dialog for depicting a quest
-class QuestReportDialog: public sigc::trackable
+class QuestReportDialog: public Decorated
 {
  public:
     QuestReportDialog(Quest *quest);
