@@ -282,11 +282,11 @@ void SplashWindow::on_load_scenario_clicked()
     d.set_parent_window(*window.get());
     
     d.run();
-    d.hide();
     
     std::string filename = d.get_scenario_filename();
     if (!filename.empty())
       {
+	d.hide();
 	GamePreferencesDialog gp(filename);
 	gp.set_parent_window(*window.get());
 	gp.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_game_started));
@@ -303,14 +303,14 @@ void SplashWindow::on_new_campaign_clicked()
     d.set_parent_window(*window.get());
     
     d.run();
-    d.hide();
     
     std::string filename = d.get_campaign_filename();
     if (!filename.empty())
       {
-	GamePreferencesDialog gp(filename);
+	d.hide();
+	GamePreferencesDialog gp(filename, true);
 	gp.set_parent_window(*window.get());
-	gp.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_game_started));
+	gp.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_campaign_started));
     
 	gp.run();
       } 
@@ -327,6 +327,11 @@ void SplashWindow::on_game_started(GameParameters g)
   new_game_requested.emit(g);
 }
 
+void SplashWindow::on_campaign_started(GameParameters g)
+{
+  new_campaign_requested.emit(g);
+}
+
 
 #if 0
 
