@@ -27,9 +27,9 @@
 #include "glade-helpers.h"
 #include "image-helpers.h"
 #include "input-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../File.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "File.h"
 
 SurrenderRefusedDialog::SurrenderRefusedDialog()
 {
@@ -40,6 +40,8 @@ SurrenderRefusedDialog::SurrenderRefusedDialog()
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
 
     Gtk::Label *label;
     xml->get_widget("label", label);
