@@ -111,10 +111,11 @@ drand(int i, int j)
 {
   float f = i / 43 * j / 43;
   f *= 10000000;
-  return (int) roundf(f) | i  + i + j;
+  return (int) roundf(f) | (i  + i + j);
 }
 
-void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
+void OverviewMap::draw_tile_pixel(SDL_Surface *surface, 
+				  SmallTile::Pattern pattern,
 				  SDL_Color first_color, SDL_Color second_color,
 				  SDL_Color third_color,
 				  int i, int j, bool shadowed)
@@ -124,10 +125,10 @@ void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
   Uint32 first = SDL_MapRGB(surface->format, c.r, c.g, c.b);
   switch (pattern)
     {
-      case Tile::SOLID:
+      case SmallTile::SOLID:
         draw_pixel(surface, i, j, first);
         break;
-      case Tile::STIPPLED:
+      case SmallTile::STIPPLED:
         {
           SDL_Color s = second_color;
           Uint32 second = SDL_MapRGB(surface->format, s.r, s.g, s.b);
@@ -138,7 +139,7 @@ void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
             draw_pixel(surface, i, j, second);
         }
         break;
-      case Tile::RANDOMIZED:
+      case SmallTile::RANDOMIZED:
         {
           SDL_Color s = second_color;
           Uint32 second = SDL_MapRGB(surface->format, s.r, s.g, s.b);
@@ -154,7 +155,7 @@ void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
             draw_pixel(surface, i, j, third);
         }
         break;
-      case Tile::DIAGONAL:
+      case SmallTile::DIAGONAL:
         {
           SDL_Color s = second_color;
           Uint32 second = SDL_MapRGB(surface->format, s.r, s.g, s.b);
@@ -170,7 +171,7 @@ void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
             draw_pixel(surface, i, j, third);
         }
         break;
-      case Tile::CROSSHATCH:
+      case SmallTile::CROSSHATCH:
         {
           SDL_Color s = second_color;
           Uint32 second = SDL_MapRGB(surface->format, s.r, s.g, s.b);
@@ -186,7 +187,7 @@ void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
             draw_pixel(surface, i, j, third);
         }
         break;
-      case Tile::SUNKEN:
+      case SmallTile::SUNKEN:
         if (shadowed == false)
           draw_pixel(surface, i, j, first);
         else
@@ -196,7 +197,7 @@ void OverviewMap::draw_tile_pixel(SDL_Surface *surface, Tile::Pattern pattern,
             draw_pixel(surface, i, j, shadow_color);
           }
         break;
-      case Tile::TABLECLOTH:
+      case SmallTile::TABLECLOTH:
           {
             SDL_Color s = second_color;
             Uint32 second = SDL_MapRGB(surface->format, s.r, s.g, s.b);
@@ -249,11 +250,11 @@ void OverviewMap::draw_tile_pixel(Maptile *t, int i, int j)
 
 int OverviewMap::calculateResizeFactor()
 {
-  if (GameMap::getWidth() <= MAP_SIZE_TINY_WIDTH && 
-      GameMap::getHeight() <= MAP_SIZE_TINY_HEIGHT)
+  if (GameMap::getWidth() <= (int)MAP_SIZE_TINY_WIDTH && 
+      GameMap::getHeight() <= (int)MAP_SIZE_TINY_HEIGHT)
     return 4;
-  else if (GameMap::getWidth() <= MAP_SIZE_SMALL_WIDTH && 
-	   GameMap::getHeight() <= MAP_SIZE_SMALL_HEIGHT)
+  else if (GameMap::getWidth() <= (int)MAP_SIZE_SMALL_WIDTH && 
+	   GameMap::getHeight() <= (int)MAP_SIZE_SMALL_HEIGHT)
     return 3;
   else
     return 2;
@@ -370,11 +371,12 @@ void OverviewMap::draw()
     for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
         it != Ruinlist::getInstance()->end(); it++)
     {
-        if (it->isHidden() == true && it->getOwner() != pl->getActiveplayer())
+        Ruin *r = *it;
+        if (r->isHidden() == true && r->getOwner() != pl->getActiveplayer())
           continue;
-        if (it->isFogged())
+        if (r->isFogged())
           continue;
-        Vector<int> pos = it->getPos();
+        Vector<int> pos = r->getPos();
         pos = mapToSurface(pos);
 
 	Uint32 raw;
@@ -388,9 +390,10 @@ void OverviewMap::draw()
     for (Templelist::iterator it = Templelist::getInstance()->begin();
         it != Templelist::getInstance()->end(); it++)
     {
-        if (it->isFogged())
+      Temple *t = *it;
+        if (t->isFogged())
           continue;
-        Vector<int> pos = it->getPos();
+        Vector<int> pos = t->getPos();
         pos = mapToSurface(pos);
 	Uint32 raw;
 	raw = SDL_MapRGB(surface->format, 255, 255, 255);
@@ -439,6 +442,13 @@ Vector<int> OverviewMap::mapFromScreen(Vector<int> pos)
 
 Vector<int> OverviewMap::mapToSurface(Vector<int> pos)
 {
+    if (pos.x < 0 || pos.y < 0
+	   || pos.x >= GameMap::getWidth() || pos.y >= GameMap::getHeight())
+      {
+	printf ("pos.x is %d, pos.y is %d\n", pos.x, pos.y);
+	printf ("width is %d, height is %d\n", GameMap::getWidth(),
+		GameMap::getHeight());
+      }
     assert(pos.x >= 0 && pos.y >= 0
 	   && pos.x < GameMap::getWidth() && pos.y < GameMap::getHeight());
 
@@ -464,15 +474,16 @@ void OverviewMap::draw_cities (bool all_razed)
   for (Citylist::iterator it = Citylist::getInstance()->begin();
       it != Citylist::getInstance()->end(); it++)
   {
+      City *c = *it;
       SDL_Surface *tmp;
-      if (it->isFogged())
+      if (c->isFogged())
         continue;
-      if (it->isBurnt() == true || all_razed == true)
+      if (c->isBurnt() == true || all_razed == true)
         tmp = gc->getSmallRuinedCityPic();
       else
-        tmp = gc->getShieldPic(0, it->getOwner());
+        tmp = gc->getShieldPic(0, c->getOwner());
   
-      Vector<int> pos = it->getPos();
+      Vector<int> pos = c->getPos();
       pos = mapToSurface(pos);
       SDL_Rect r;
       r.x = pos.x - (tmp->w/2);
