@@ -77,7 +77,8 @@ sigc::signal<void, Player::Type> sendingTurn;
 Player::Player(string name, Uint32 armyset, SDL_Color color, int width,
 	       int height, Type type, int player_no)
     :d_color(color), d_name(name), d_armyset(armyset), d_gold(1000),
-    d_dead(false), d_immortal(false), d_type(type), d_upkeep(0), d_income(0)
+    d_dead(false), d_immortal(false), d_type(type), d_upkeep(0), d_income(0),
+    d_observable(true)
 {
     if (player_no != -1)
 	d_id = player_no;
@@ -113,7 +114,7 @@ Player::Player(const Player& player)
     d_gold(player.d_gold), d_dead(player.d_dead), d_immortal(player.d_immortal),
     d_type(player.d_type), d_id(player.d_id), 
     d_fight_order(player.d_fight_order), d_upkeep(player.d_upkeep), 
-    d_income(player.d_income)
+    d_income(player.d_income), d_observable(player.d_observable)
 {
     // as the other player is propably dumped somehow, we need to deep copy
     // everything. This costs a lot, but the only useful situation for this
@@ -227,6 +228,7 @@ Player::Player(XML_Helper* helper)
             sdiplomatic_scores >> val;
 	    d_diplomatic_score[i] = val;
     }
+    helper->getData(d_observable, "observable");
 
     helper->registerTag(Action::d_tag, sigc::mem_fun(this, &Player::load));
     helper->registerTag(History::d_tag, sigc::mem_fun(this, &Player::load));
@@ -356,7 +358,7 @@ SDL_Color Player::getMaskColor() const
 void Player::addGold(int gold)
 {
     d_gold += gold;
-    schangingStatus.emit();
+    schangingStats.emit();
 }
 
 void Player::withdrawGold(int gold)
@@ -364,7 +366,7 @@ void Player::withdrawGold(int gold)
     d_gold -= gold;
     if (d_gold < 0)
       d_gold = 0; /* bankrupt.  should we start turning off city production? */
-    schangingStatus.emit();
+    schangingStats.emit();
 }
 
 std::string Player::getName(bool translate) const
@@ -442,6 +444,7 @@ void Player::doKill()
         // ignore it
         return;
 
+    d_observable = false;
     History_PlayerVanquished* item;
     item = new History_PlayerVanquished();
     addHistory(item);
@@ -522,6 +525,8 @@ bool Player::save(XML_Helper* helper) const
       }
     retval &= helper->saveData("diplomatic_scores", diplomatic_scores.str());
 
+    retval &= helper->saveData("observable", d_observable);
+
     //save the actionlist
     for (list<Action*>::const_iterator it = d_actions.begin();
             it != d_actions.end(); it++)
@@ -705,15 +710,13 @@ bool Player::stackSplit(Stack* s)
 void Player::doStackJoin(Stack* receiver, Stack* joining, bool grouped)
 {
     // Now if grouped is set to false, ungroup all the receiving stack's armies
-    // (by default, only the joining stacks armies will continue to move). Note
-    // that the computer player silently ignores the grouped value and always
-    // moves all armies in a stack.
+    // (by default, only the joining stacks armies will continue to move). 
     for (Stack::iterator it = receiver->begin(); it != receiver->end(); it++)
         (*it)->setGrouped(grouped);
 
     for (Stack::iterator it = joining->begin(); it != joining->end(); it++)
     {
-        receiver->push_back(*it);
+        receiver->push_front(*it);
         (*it)->setGrouped(true);
     }
 
@@ -732,6 +735,7 @@ bool Player::stackJoin(Stack* receiver, Stack* joining, bool grouped)
 
     if (joining->canJoin(receiver) == false)
       {
+	//fixme: this is a bad idea.  it seems recursively bad.
 	Stack *already_there = Stacklist::getAmbiguity(joining);
 	stackJoin(joining, already_there,  false);
         return false;
@@ -854,7 +858,8 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
     }
 
     int stepCount = 0;
-    while (s->getPath()->size() > 1 && stackMoveOneStep(s))
+    while (s->getPath()->size() > 1 && stackMoveOneStep(s) ||
+	   stackMoveOneStepOverTooLargeFriendlyStacks(s))
       {
 	stepCount++;
         supdatingStack.emit(0);
@@ -1015,11 +1020,44 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
     return moveResult;
 }
 
+	   
+bool Player::stackMoveOneStepOverTooLargeFriendlyStacks(Stack *s)
+{
+  if (!s)
+    return false;
+
+  if (!s->enoughMoves())
+    return false;
+
+  if (s->getPath()->size() <= 1)
+    return false;
+
+  Vector<int> dest = *s->getPath()->front();
+  Stack *another_stack = d_stacklist->getObjectAt(dest);
+  if (!another_stack)
+    return false;
+
+  if (another_stack->getOwner() != s->getOwner())
+    return false;
+
+  if (d_stacklist->canJumpOverTooLargeStack(s) == false)
+    return false;
+
+  Action_Move* item = new Action_Move();
+  item->fillData(s, dest);
+  addAction(item);
+
+  s->moveOneStep(true);
+  return true;
+}
+
 bool Player::stackMoveOneStep(Stack* s)
 {
   if (!s)
     return false;
 
+  sbusy.emit();
+
   if (!s->enoughMoves())
     return false;
 
@@ -2298,6 +2336,20 @@ void Player::doProposeDiplomacy (DiplomaticProposal proposal, Player *player)
     return;
   if (proposal == d_diplomatic_proposal[player->getId()])
     return;
+  if (proposal == PROPOSE_PEACE)
+    {
+      std::string s = _("Peace negotiated with ") + player->getName();
+      if (getDiplomaticState(player) == AT_PEACE ||
+	  getDiplomaticProposal(player) == PROPOSE_PEACE)
+	schangingStatus.emit(s);
+    }
+  else if (proposal == PROPOSE_WAR)
+    {
+      std::string s = _("War declared with ") + player->getName();
+      if (getDiplomaticState(player) == AT_WAR ||
+	  getDiplomaticProposal(player) == PROPOSE_WAR)
+      schangingStatus.emit(s);
+    }
   d_diplomatic_proposal[player->getId()] = proposal;
 }
 
@@ -3096,4 +3148,31 @@ void Player::loadPbmGame()
       history_written.emit(copy);
     }
 }
+
+void Player::saveNetworkActions(XML_Helper *helper)
+{
+  for (list<Action*>::const_iterator it = d_actions.begin();
+       it != d_actions.end(); it++)
+    {
+      NetworkAction *copy = new NetworkAction(*it, this);
+      copy->save(helper);
+    }
+}
+	
+bool Player::conqueredCity(City *c)
+{
+  if (!c)
+    return false;
+  for (list<History*>::const_iterator it = d_history.begin();
+       it != d_history.end(); it++)
+    {
+      if ((*it)->getType() == History::CITY_WON)
+	{
+	  History_CityWon *event = dynamic_cast<History_CityWon*>(*it);
+	  if (event->getCityId() == c->getId())
+	    return true;
+	}
+    }    
+  return false;
+}
 // End of file
