@@ -468,6 +468,8 @@ class Player: public sigc::trackable
          */
         static Player* loadPlayer(XML_Helper* helper);
 
+	void saveNetworkActions(XML_Helper *helper);
+
         /** 
 	 * This function is called when a player's turn starts. 
 	 * For AI players this function should start the algorithm.
@@ -1119,6 +1121,10 @@ class Player: public sigc::trackable
         bool heroPlantStandard(Stack *stack);
 
 	void cityTooPoorToProduce(City *city, int slot);
+
+	bool isObservable() const {return d_observable;};
+	void setObservable(bool observable) {d_observable = observable;};
+
 	/**
 	 * @param city   The city being invaded.
 	 * @param loot   The gold looted.
@@ -1209,8 +1215,14 @@ class Player: public sigc::trackable
 	/**
 	 * Emitted when the player's treasury has been changed.
 	 */
-        //! Emitted whenever a player's status changes.
-        sigc::signal<void> schangingStatus;
+        //! Emitted whenever a player's stats changes.
+        sigc::signal<void> schangingStats;
+
+	//! Emitted whenever a computer player does something of note.
+        sigc::signal<void, std::string> schangingStatus;
+
+	//! Emitted whenever any player does anything at all.
+	sigc::signal<void> sbusy;
 
 	/**
 	 * Emitted when the player's stack moves, is disbanded, gets blessed,
@@ -1284,6 +1296,8 @@ class Player: public sigc::trackable
 	bool hasAlreadyInitializedTurn() const;
 	bool hasAlreadyEndedTurn() const;
 	void loadPbmGame();
+	//! Check the history to see if we ever conquered the given city.
+	bool conqueredCity(City *c);
     protected:
         // do some fight cleaning up, setting
         void cleanupAfterFight(std::list<Stack*> &attackers,
@@ -1292,6 +1306,9 @@ class Player: public sigc::trackable
         //! Move stack s one step forward on it's Path.
         bool stackMoveOneStep(Stack* s);
 
+	//! Move stack s one step forward on it's Path, over another stack.
+	bool stackMoveOneStepOverTooLargeFriendlyStacks(Stack *s);
+
         void addAction(Action *action);
 
         // DATA
@@ -1364,6 +1381,9 @@ class Player: public sigc::trackable
 	//! A quantification of how much this Player likes every other Player.
 	Uint32 d_diplomatic_score[MAX_PLAYERS];
 
+	//! Whether or not this player is observable by the user.
+	bool d_observable;
+
 	//! assists in scorekeeping for diplomacy
 	void alterDiplomaticRelationshipScore (Player *player, int amount);
 
