@@ -51,7 +51,6 @@ using namespace std;
 std::string Playerlist::d_tag = "playerlist";
 Playerlist* Playerlist::s_instance = 0;
 Player* Playerlist::d_activeplayer = 0;
-bool Playerlist::s_finish = false;
 
 Playerlist* Playerlist::getInstance()
 {
@@ -83,7 +82,6 @@ void Playerlist::deleteInstance()
 Playerlist::Playerlist()
     :d_neutral(0)
 {
-    s_finish = false;
     d_activeplayer = 0;
 }
 
@@ -95,7 +93,6 @@ Playerlist::Playerlist(XML_Helper* helper)
     //the size; we don't use it yet) and active(which player is active)
     //we do it by calling load with playerlist as string
     load(Playerlist::d_tag, helper);
-    s_finish = false;
 
     helper->registerTag(Player::d_tag, sigc::mem_fun(this, &Playerlist::load));
 }
@@ -228,13 +225,6 @@ Player* Playerlist::getFirstLiving() const
             return (*it);
 }
 
-Player* Playerlist::getFirstHuman() const
-{
-    for (const_iterator it = begin(); ; it++)
-        if (!(*it)->isDead() && (*it)->getType() == Player::HUMAN)
-            return (*it);
-}
-
 bool Playerlist::save(XML_Helper* helper) const
 {
     //to prevent segfaults
@@ -374,7 +364,7 @@ void Playerlist::calculateDiplomaticRankings()
       for (unsigned int j = 0; j < MAX_PLAYERS; j++)
 	{
 	  if (deplete[j] == i)
-	    titles[j] = _("");
+	    titles[j] = "";
 	}
     }
   for (unsigned int i = 0; i < MAX_PLAYERS; i++)
