@@ -20,7 +20,7 @@
 #ifndef RUIN_H
 #define RUIN_H
 
-#define DEFAULT_RUIN_NAME  ""
+#define DEFAULT_RUIN_NAME  "Ruin"
 #include <string>
 #include <sigc++/trackable.h>
 #include "NamedLocation.h"
@@ -140,6 +140,10 @@ class Ruin : public NamedLocation, public sigc::trackable
 	 */
 	void populateWithRandomReward();
 
+	bool isUnnamed() {return getName() == getDefaultName() ? true : false;};
+	
+	static std::string getDefaultName() {return DEFAULT_RUIN_NAME;};
+
     private:
         // DATA
 	//! Whether or not the Ruin has already successfully been searched.
