@@ -24,10 +24,13 @@
 #include "ruinlist.h"
 #include "xmlhelper.h"
 #include "playerlist.h"
+#include "reward.h"
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
+std::string Ruinlist::d_tag = "ruinlist";
+
 Ruinlist* Ruinlist::s_instance = 0;
 
 Ruinlist* Ruinlist::getInstance()
@@ -61,17 +64,17 @@ Ruinlist::Ruinlist()
 
 Ruinlist::Ruinlist(XML_Helper* helper)
 {
-    helper->registerTag("ruin", sigc::mem_fun(this, &Ruinlist::load));
+    helper->registerTag(Ruin::d_tag, sigc::mem_fun(this, &Ruinlist::load));
 }
 
 bool Ruinlist::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("ruinlist");
+    retval &= helper->openTag(Ruinlist::d_tag);
 
     for (const_iterator it = begin(); it != end(); it++)
-        retval &= (*it).save(helper);
+        retval &= (*it)->save(helper);
     
     retval &= helper->closeTag();
 
@@ -81,17 +84,16 @@ bool Ruinlist::save(XML_Helper* helper) const
 bool Ruinlist::load(std::string tag, XML_Helper* helper)
 {
     // Shouldn't happen, but one never knows...
-    if (tag != "ruin")
+    if (tag != Ruin::d_tag)
         return false;
 
-    Ruin r(helper);
-    push_front(r);
+    push_front(new Ruin(helper));
 
     //! since the ruin has only now been copied to its final state, we need
     //to register the callback for the occupants here.
-    helper->registerTag("stack", sigc::mem_fun(*begin(), &Ruin::load));
+    helper->registerTag(Stack::d_tag, sigc::mem_fun(*begin(), &Ruin::load));
     // same with rewards in ruins
-    helper->registerTag("reward", sigc::mem_fun(*begin(), &Ruin::load));
+    helper->registerTag(Reward::d_tag, sigc::mem_fun(*begin(), &Ruin::load));
 
     return true;
 }
@@ -157,7 +159,7 @@ Ruin* Ruinlist::getNearestVisibleRuin(const Vector<int>& pos, int dist)
 void Ruinlist::changeOwnership(Player *old_owner, Player *new_owner)
 {
   for (iterator it = begin(); it != end(); it++)
-    if ((*it).getOwner() == old_owner)
-      (*it).setOwner(new_owner);
+    if ((*it)->getOwner() == old_owner)
+      (*it)->setOwner(new_owner);
 }
 
