@@ -24,10 +24,11 @@
 #include "shieldset.h"
 #include "shieldstyle.h"
 #include "File.h"
-#include "defs.h"
 
 using namespace std;
 
+std::string Shieldset::d_tag = "shieldset";
+
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 //#define debug(x)
 
@@ -41,9 +42,9 @@ Shieldset::Shieldset(XML_Helper *helper)
   helper->getData(d_medium_height, "medium_height");
   helper->getData(d_large_width, "large_width");
   helper->getData(d_large_height, "large_height");
-  helper->registerTag("shield", sigc::mem_fun((*this), 
-					      &Shieldset::loadShield));
-  helper->registerTag("shieldstyle", sigc::mem_fun((*this), 
+  helper->registerTag(Shield::d_tag, 
+		      sigc::mem_fun((*this), &Shieldset::loadShield));
+  helper->registerTag(ShieldStyle::d_tag, sigc::mem_fun((*this), 
 						   &Shieldset::loadShield));
 }
 
@@ -55,13 +56,13 @@ Shieldset::~Shieldset()
 
 bool Shieldset::loadShield(string tag, XML_Helper* helper)
 {
-    if (tag == "shield")
+    if (tag == Shield::d_tag)
       {
 	Shield* sh = new Shield(helper);
 	push_back(sh);
 	return true;
       }
-    if (tag == "shieldstyle")
+    if (tag == ShieldStyle::d_tag)
       {
 	ShieldStyle *sh = new ShieldStyle(helper);
 	(*back()).push_back(sh);
@@ -91,9 +92,7 @@ SDL_Color Shieldset::getColor(Uint32 owner)
 	return (*it)->getColor();
     }
   SDL_Color def;
-  def.r= 0;
-  def.g= 0;
-  def.b= 0;
+  memset (&def, 0, sizeof (def));
   return def;
 }
 
@@ -105,9 +104,7 @@ SDL_Color Shieldset::getMaskColor(Uint32 owner)
 	return (*it)->getMaskColor();
     }
   SDL_Color def;
-  def.r= 0;
-  def.g= 0;
-  def.b= 0;
+  memset (&def, 0, sizeof (def));
   return def;
 }
 
