@@ -118,18 +118,18 @@ void Stack::setPlayer(Player* p)
     (*it)->setOwner(p);
 }
 
-void Stack::moveOneStep()
+void Stack::moveOneStep(bool skipping)
 {
-  debug("move_one_step()");
+  debug("moveOneStep()");
 
   Vector<int> dest = *getPath()->front();
-  moveToDest(dest);
+  moveToDest(dest, skipping);
 
   //now remove first point of the path
   d_path->eraseFirstPoint();
 }
 
-void Stack::moveToDest(Vector<int> dest)
+void Stack::moveToDest(Vector<int> dest, bool skipping)
 {
   Vector<int> pos = getPos();
     
@@ -138,24 +138,35 @@ void Stack::moveToDest(Vector<int> dest)
   City* on_city = Citylist::getInstance()->getObjectAt(pos.x, pos.y);
   Port* on_port = Portlist::getInstance()->getObjectAt(pos.x, pos.y);
   Bridge* on_bridge= Bridgelist::getInstance()->getObjectAt(pos.x, pos.y);
+  Bridge* to_bridge= Bridgelist::getInstance()->getObjectAt(dest.x, dest.y);
   bool on_water = (GameMap::getInstance()->getTile(pos.x,pos.y)->getMaptileType() == Tile::WATER);
   bool to_water = (GameMap::getInstance()->getTile(dest.x,dest.y)->getMaptileType() == Tile::WATER);
   bool ship_load_unload = false;
   //here we mark the armies as being on or off a boat
   if (!isFlying())
     {
-      if ((on_water && to_city) || 
-	  (on_water && (on_port || on_bridge) && !to_water) ||
-	  ((on_city || on_port || on_bridge) && to_water))
+      /* skipping refers to when we have to move over another friendly stack
+       * of a size that's too big to join with. */
+      if ((on_water && to_city && !on_bridge) || 
+	  (on_water && on_port && !to_water && hasShip()) ||
+	  ((on_city || on_port) && to_water && !to_bridge) ||
+	  (on_bridge && to_water && !to_bridge) ||
+	  (on_bridge && !to_water && hasShip()) ||
+	  (on_water && to_water && !on_bridge && !on_port && !to_bridge &&
+	   hasShip() == false) ||
+	  (!on_water && !to_water && hasShip() == true))
 	{
-	  ship_load_unload = true;
-	  for (Stack::iterator it = begin(); it != end(); it++)
+	  if (!skipping)
 	    {
-	      if (to_water && 
-		  ((*it)->getStat(Army::MOVE_BONUS) & Tile::WATER) == 0)
-		(*it)->setInShip(true);
-	      else
-		(*it)->setInShip(false);
+	      ship_load_unload = true;
+	      for (Stack::iterator it = begin(); it != end(); it++)
+		{
+		  if (to_water && 
+		      ((*it)->getStat(Army::MOVE_BONUS) & Tile::WATER) == 0)
+		    (*it)->setInShip(true);
+		  else
+		    (*it)->setInShip(false);
+		}
 	    }
 	}
     }
@@ -335,6 +346,7 @@ Uint32 Stack::countGroupedArmies() const
 
 void Stack::group()
 {
+  debug("Stack::group()")
   if (empty())
     return;
   for (iterator it = begin(); it != end(); ++it)
@@ -344,6 +356,7 @@ void Stack::group()
 
 void Stack::ungroup()
 {
+  debug("Stack::ungroup()")
   if (empty())
     return;
   for (iterator it = begin(); it != end(); ++it)
@@ -377,7 +390,7 @@ void Stack::getHeroes(std::vector<Uint32>& dst) const
     for (const_iterator it = begin(); it != end(); ++it)
       {
 	// if hero - add it to the vector
-	debug("Army type: " << (*it)->getType())
+	debug("Army type: " << (*it)->getTypeId())
 	  if ((*it)->isHero() && (*it)->getHP() > 0)
 	    dst.push_back((*it)->getId());
       }
@@ -674,8 +687,6 @@ bool Stack::armyCompareFightOrder (const Army *lhs, const Army *rhs)
   std::list<Uint32> rhs_fight_order = rhs->getOwner()->getFightOrder();
   Uint32 lhs_rank = getFightOrder (lhs_fight_order, lhs->getTypeId());
   Uint32 rhs_rank = getFightOrder (rhs_fight_order, rhs->getTypeId());
-  //if (lhs_rank == rhs_rank)
-    //return lhs->getId() < rhs->getId();
   return lhs_rank < rhs_rank; 
 }
 
